# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessageContent(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessageContent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'content_type': 'str',
            'location': 'ContentLocation',
            'attachment': 'ContentAttachment',
            'quick_reply': 'ContentQuickReply',
            'generic': 'ContentGeneric',
            'list': 'ContentList',
            'template': 'ContentNotificationTemplate',
            'reactions': 'list[ContentReaction]',
            'mention': 'MessagingRecipient',
            'postback': 'ContentPostback'
        }

        self.attribute_map = {
            'content_type': 'contentType',
            'location': 'location',
            'attachment': 'attachment',
            'quick_reply': 'quickReply',
            'generic': 'generic',
            'list': 'list',
            'template': 'template',
            'reactions': 'reactions',
            'mention': 'mention',
            'postback': 'postback'
        }

        self._content_type = None
        self._location = None
        self._attachment = None
        self._quick_reply = None
        self._generic = None
        self._list = None
        self._template = None
        self._reactions = None
        self._mention = None
        self._postback = None

    @property
    def content_type(self):
        """
        Gets the content_type of this MessageContent.
        Type of this content element. If contentType = \"Attachment\" only one item is allowed.

        :return: The content_type of this MessageContent.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this MessageContent.
        Type of this content element. If contentType = \"Attachment\" only one item is allowed.

        :param content_type: The content_type of this MessageContent.
        :type: str
        """
        allowed_values = ["Attachment", "Location", "QuickReply", "Notification", "GenericTemplate", "ListTemplate", "Postback", "Reactions", "Mention"]
        if content_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for content_type -> " + content_type)
            self._content_type = "outdated_sdk_version"
        else:
            self._content_type = content_type

    @property
    def location(self):
        """
        Gets the location of this MessageContent.
        Location object

        :return: The location of this MessageContent.
        :rtype: ContentLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this MessageContent.
        Location object

        :param location: The location of this MessageContent.
        :type: ContentLocation
        """
        
        self._location = location

    @property
    def attachment(self):
        """
        Gets the attachment of this MessageContent.
        Attachment object

        :return: The attachment of this MessageContent.
        :rtype: ContentAttachment
        """
        return self._attachment

    @attachment.setter
    def attachment(self, attachment):
        """
        Sets the attachment of this MessageContent.
        Attachment object

        :param attachment: The attachment of this MessageContent.
        :type: ContentAttachment
        """
        
        self._attachment = attachment

    @property
    def quick_reply(self):
        """
        Gets the quick_reply of this MessageContent.
        Quick reply object

        :return: The quick_reply of this MessageContent.
        :rtype: ContentQuickReply
        """
        return self._quick_reply

    @quick_reply.setter
    def quick_reply(self, quick_reply):
        """
        Sets the quick_reply of this MessageContent.
        Quick reply object

        :param quick_reply: The quick_reply of this MessageContent.
        :type: ContentQuickReply
        """
        
        self._quick_reply = quick_reply

    @property
    def generic(self):
        """
        Gets the generic of this MessageContent.
        Generic content object

        :return: The generic of this MessageContent.
        :rtype: ContentGeneric
        """
        return self._generic

    @generic.setter
    def generic(self, generic):
        """
        Sets the generic of this MessageContent.
        Generic content object

        :param generic: The generic of this MessageContent.
        :type: ContentGeneric
        """
        
        self._generic = generic

    @property
    def list(self):
        """
        Gets the list of this MessageContent.
        List content object

        :return: The list of this MessageContent.
        :rtype: ContentList
        """
        return self._list

    @list.setter
    def list(self, list):
        """
        Sets the list of this MessageContent.
        List content object

        :param list: The list of this MessageContent.
        :type: ContentList
        """
        
        self._list = list

    @property
    def template(self):
        """
        Gets the template of this MessageContent.
        Template notification object

        :return: The template of this MessageContent.
        :rtype: ContentNotificationTemplate
        """
        return self._template

    @template.setter
    def template(self, template):
        """
        Sets the template of this MessageContent.
        Template notification object

        :param template: The template of this MessageContent.
        :type: ContentNotificationTemplate
        """
        
        self._template = template

    @property
    def reactions(self):
        """
        Gets the reactions of this MessageContent.
        A list of reactions

        :return: The reactions of this MessageContent.
        :rtype: list[ContentReaction]
        """
        return self._reactions

    @reactions.setter
    def reactions(self, reactions):
        """
        Sets the reactions of this MessageContent.
        A list of reactions

        :param reactions: The reactions of this MessageContent.
        :type: list[ContentReaction]
        """
        
        self._reactions = reactions

    @property
    def mention(self):
        """
        Gets the mention of this MessageContent.
        This is used to identify who the message is sent to, as well as who it was sent from. This information is channel specific - depends on capabilities to describe party by the platform

        :return: The mention of this MessageContent.
        :rtype: MessagingRecipient
        """
        return self._mention

    @mention.setter
    def mention(self, mention):
        """
        Sets the mention of this MessageContent.
        This is used to identify who the message is sent to, as well as who it was sent from. This information is channel specific - depends on capabilities to describe party by the platform

        :param mention: The mention of this MessageContent.
        :type: MessagingRecipient
        """
        
        self._mention = mention

    @property
    def postback(self):
        """
        Gets the postback of this MessageContent.
        The postback object result of a user clicking in a button

        :return: The postback of this MessageContent.
        :rtype: ContentPostback
        """
        return self._postback

    @postback.setter
    def postback(self, postback):
        """
        Sets the postback of this MessageContent.
        The postback object result of a user clicking in a button

        :param postback: The postback of this MessageContent.
        :type: ContentPostback
        """
        
        self._postback = postback

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class GroupGreetingEventGreeting(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        GroupGreetingEventGreeting - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'type': 'str',
            'owner_type': 'str',
            'owner': 'GroupGreetingEventGreetingOwner',
            'greeting_audio_file': 'GroupGreetingEventGreetingAudioFile',
            'audio_tts': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'type': 'type',
            'owner_type': 'ownerType',
            'owner': 'owner',
            'greeting_audio_file': 'greetingAudioFile',
            'audio_tts': 'audioTTS'
        }

        self._id = None
        self._name = None
        self._type = None
        self._owner_type = None
        self._owner = None
        self._greeting_audio_file = None
        self._audio_tts = None

    @property
    def id(self):
        """
        Gets the id of this GroupGreetingEventGreeting.


        :return: The id of this GroupGreetingEventGreeting.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this GroupGreetingEventGreeting.


        :param id: The id of this GroupGreetingEventGreeting.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this GroupGreetingEventGreeting.


        :return: The name of this GroupGreetingEventGreeting.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this GroupGreetingEventGreeting.


        :param name: The name of this GroupGreetingEventGreeting.
        :type: str
        """
        
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this GroupGreetingEventGreeting.


        :return: The type of this GroupGreetingEventGreeting.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this GroupGreetingEventGreeting.


        :param type: The type of this GroupGreetingEventGreeting.
        :type: str
        """
        
        self._type = type

    @property
    def owner_type(self):
        """
        Gets the owner_type of this GroupGreetingEventGreeting.


        :return: The owner_type of this GroupGreetingEventGreeting.
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """
        Sets the owner_type of this GroupGreetingEventGreeting.


        :param owner_type: The owner_type of this GroupGreetingEventGreeting.
        :type: str
        """
        
        self._owner_type = owner_type

    @property
    def owner(self):
        """
        Gets the owner of this GroupGreetingEventGreeting.


        :return: The owner of this GroupGreetingEventGreeting.
        :rtype: GroupGreetingEventGreetingOwner
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this GroupGreetingEventGreeting.


        :param owner: The owner of this GroupGreetingEventGreeting.
        :type: GroupGreetingEventGreetingOwner
        """
        
        self._owner = owner

    @property
    def greeting_audio_file(self):
        """
        Gets the greeting_audio_file of this GroupGreetingEventGreeting.


        :return: The greeting_audio_file of this GroupGreetingEventGreeting.
        :rtype: GroupGreetingEventGreetingAudioFile
        """
        return self._greeting_audio_file

    @greeting_audio_file.setter
    def greeting_audio_file(self, greeting_audio_file):
        """
        Sets the greeting_audio_file of this GroupGreetingEventGreeting.


        :param greeting_audio_file: The greeting_audio_file of this GroupGreetingEventGreeting.
        :type: GroupGreetingEventGreetingAudioFile
        """
        
        self._greeting_audio_file = greeting_audio_file

    @property
    def audio_tts(self):
        """
        Gets the audio_tts of this GroupGreetingEventGreeting.


        :return: The audio_tts of this GroupGreetingEventGreeting.
        :rtype: str
        """
        return self._audio_tts

    @audio_tts.setter
    def audio_tts(self, audio_tts):
        """
        Sets the audio_tts of this GroupGreetingEventGreeting.


        :param audio_tts: The audio_tts of this GroupGreetingEventGreeting.
        :type: str
        """
        
        self._audio_tts = audio_tts

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Call(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Call - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'direction': 'str',
            'recording': 'bool',
            'recording_state': 'str',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'recording_id': 'str',
            'segments': 'list[Segment]',
            'error_info': 'ErrorInfo',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'document_id': 'str',
            'start_alerting_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'disconnect_reasons': 'list[DisconnectReason]',
            'fax_status': 'FaxStatus',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'uui_data': 'str',
            'pcSelf': 'Address',
            'other': 'Address',
            'wrapup': 'Wrapup',
            'after_call_work': 'AfterCallWork',
            'after_call_work_required': 'bool',
            'agent_assistant_id': 'str'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'direction': 'direction',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'recording_id': 'recordingId',
            'segments': 'segments',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'document_id': 'documentId',
            'start_alerting_time': 'startAlertingTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'disconnect_reasons': 'disconnectReasons',
            'fax_status': 'faxStatus',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'uui_data': 'uuiData',
            'pcSelf': 'self',
            'other': 'other',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'agent_assistant_id': 'agentAssistantId'
        }

        self._state = None
        self._id = None
        self._direction = None
        self._recording = None
        self._recording_state = None
        self._muted = None
        self._confined = None
        self._held = None
        self._recording_id = None
        self._segments = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._document_id = None
        self._start_alerting_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._disconnect_reasons = None
        self._fax_status = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._uui_data = None
        self._pcSelf = None
        self._other = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._agent_assistant_id = None

    @property
    def state(self):
        """
        Gets the state of this Call.
        The connection state of this communication.

        :return: The state of this Call.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Call.
        The connection state of this communication.

        :param state: The state of this Call.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this Call.
        A globally unique identifier for this communication.

        :return: The id of this Call.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Call.
        A globally unique identifier for this communication.

        :param id: The id of this Call.
        :type: str
        """
        
        self._id = id

    @property
    def direction(self):
        """
        Gets the direction of this Call.
        The direction of the call

        :return: The direction of this Call.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this Call.
        The direction of the call

        :param direction: The direction of this Call.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def recording(self):
        """
        Gets the recording of this Call.
        True if this call is being recorded.

        :return: The recording of this Call.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this Call.
        True if this call is being recorded.

        :param recording: The recording of this Call.
        :type: bool
        """
        
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this Call.
        State of recording on this call.

        :return: The recording_state of this Call.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this Call.
        State of recording on this call.

        :param recording_state: The recording_state of this Call.
        :type: str
        """
        allowed_values = ["none", "active", "paused"]
        if recording_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for recording_state -> " + recording_state)
            self._recording_state = "outdated_sdk_version"
        else:
            self._recording_state = recording_state

    @property
    def muted(self):
        """
        Gets the muted of this Call.
        True if this call is muted so that remote participants can't hear any audio from this end.

        :return: The muted of this Call.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this Call.
        True if this call is muted so that remote participants can't hear any audio from this end.

        :param muted: The muted of this Call.
        :type: bool
        """
        
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this Call.
        True if this call is held and the person on this side hears hold music.

        :return: The confined of this Call.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this Call.
        True if this call is held and the person on this side hears hold music.

        :param confined: The confined of this Call.
        :type: bool
        """
        
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this Call.
        True if this call is held and the person on this side hears silence.

        :return: The held of this Call.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this Call.
        True if this call is held and the person on this side hears silence.

        :param held: The held of this Call.
        :type: bool
        """
        
        self._held = held

    @property
    def recording_id(self):
        """
        Gets the recording_id of this Call.
        A globally unique identifier for the recording associated with this call.

        :return: The recording_id of this Call.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this Call.
        A globally unique identifier for the recording associated with this call.

        :param recording_id: The recording_id of this Call.
        :type: str
        """
        
        self._recording_id = recording_id

    @property
    def segments(self):
        """
        Gets the segments of this Call.
        The time line of the participant's call, divided into activity segments.

        :return: The segments of this Call.
        :rtype: list[Segment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this Call.
        The time line of the participant's call, divided into activity segments.

        :param segments: The segments of this Call.
        :type: list[Segment]
        """
        
        self._segments = segments

    @property
    def error_info(self):
        """
        Gets the error_info of this Call.


        :return: The error_info of this Call.
        :rtype: ErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this Call.


        :param error_info: The error_info of this Call.
        :type: ErrorInfo
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Call.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :return: The disconnect_type of this Call.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Call.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :param disconnect_type: The disconnect_type of this Call.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "timeout", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this Call.
        The timestamp the call was placed on hold in the cloud clock if the call is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_hold_time of this Call.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this Call.
        The timestamp the call was placed on hold in the cloud clock if the call is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_hold_time: The start_hold_time of this Call.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def document_id(self):
        """
        Gets the document_id of this Call.
        If call is an outbound fax of a document from content management, then this is the id in content management.

        :return: The document_id of this Call.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this Call.
        If call is an outbound fax of a document from content management, then this is the id in content management.

        :param document_id: The document_id of this Call.
        :type: str
        """
        
        self._document_id = document_id

    @property
    def start_alerting_time(self):
        """
        Gets the start_alerting_time of this Call.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_alerting_time of this Call.
        :rtype: datetime
        """
        return self._start_alerting_time

    @start_alerting_time.setter
    def start_alerting_time(self, start_alerting_time):
        """
        Sets the start_alerting_time of this Call.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_alerting_time: The start_alerting_time of this Call.
        :type: datetime
        """
        
        self._start_alerting_time = start_alerting_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Call.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The connected_time of this Call.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Call.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param connected_time: The connected_time of this Call.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Call.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The disconnected_time of this Call.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Call.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param disconnected_time: The disconnected_time of this Call.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def disconnect_reasons(self):
        """
        Gets the disconnect_reasons of this Call.
        List of reasons that this call was disconnected. This will be set once the call disconnects.

        :return: The disconnect_reasons of this Call.
        :rtype: list[DisconnectReason]
        """
        return self._disconnect_reasons

    @disconnect_reasons.setter
    def disconnect_reasons(self, disconnect_reasons):
        """
        Sets the disconnect_reasons of this Call.
        List of reasons that this call was disconnected. This will be set once the call disconnects.

        :param disconnect_reasons: The disconnect_reasons of this Call.
        :type: list[DisconnectReason]
        """
        
        self._disconnect_reasons = disconnect_reasons

    @property
    def fax_status(self):
        """
        Gets the fax_status of this Call.
        Extra information on fax transmission.

        :return: The fax_status of this Call.
        :rtype: FaxStatus
        """
        return self._fax_status

    @fax_status.setter
    def fax_status(self, fax_status):
        """
        Sets the fax_status of this Call.
        Extra information on fax transmission.

        :param fax_status: The fax_status of this Call.
        :type: FaxStatus
        """
        
        self._fax_status = fax_status

    @property
    def provider(self):
        """
        Gets the provider of this Call.
        The source provider for the call.

        :return: The provider of this Call.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this Call.
        The source provider for the call.

        :param provider: The provider of this Call.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this Call.
        The UUID of the script to use.

        :return: The script_id of this Call.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this Call.
        The UUID of the script to use.

        :param script_id: The script_id of this Call.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this Call.
        The id of the peer communication corresponding to a matching leg for this communication.

        :return: The peer_id of this Call.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this Call.
        The id of the peer communication corresponding to a matching leg for this communication.

        :param peer_id: The peer_id of this Call.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def uui_data(self):
        """
        Gets the uui_data of this Call.
        User to User Information (UUI) data managed by SIP session application.

        :return: The uui_data of this Call.
        :rtype: str
        """
        return self._uui_data

    @uui_data.setter
    def uui_data(self, uui_data):
        """
        Sets the uui_data of this Call.
        User to User Information (UUI) data managed by SIP session application.

        :param uui_data: The uui_data of this Call.
        :type: str
        """
        
        self._uui_data = uui_data

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this Call.
        Address and name data for a call endpoint.

        :return: The pcSelf of this Call.
        :rtype: Address
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this Call.
        Address and name data for a call endpoint.

        :param pcSelf: The pcSelf of this Call.
        :type: Address
        """
        
        self._pcSelf = pcSelf

    @property
    def other(self):
        """
        Gets the other of this Call.
        Address and name data for a call endpoint.

        :return: The other of this Call.
        :rtype: Address
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this Call.
        Address and name data for a call endpoint.

        :param other: The other of this Call.
        :type: Address
        """
        
        self._other = other

    @property
    def wrapup(self):
        """
        Gets the wrapup of this Call.
        Call wrap up or disposition data.

        :return: The wrapup of this Call.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this Call.
        Call wrap up or disposition data.

        :param wrapup: The wrapup of this Call.
        :type: Wrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this Call.
        After-call work for the communication.

        :return: The after_call_work of this Call.
        :rtype: AfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this Call.
        After-call work for the communication.

        :param after_call_work: The after_call_work of this Call.
        :type: AfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this Call.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :return: The after_call_work_required of this Call.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this Call.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :param after_call_work_required: The after_call_work_required of this Call.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def agent_assistant_id(self):
        """
        Gets the agent_assistant_id of this Call.
        UUID of virtual agent assistant that provide suggestions to the agent participant during the conversation.

        :return: The agent_assistant_id of this Call.
        :rtype: str
        """
        return self._agent_assistant_id

    @agent_assistant_id.setter
    def agent_assistant_id(self, agent_assistant_id):
        """
        Sets the agent_assistant_id of this Call.
        UUID of virtual agent assistant that provide suggestions to the agent participant during the conversation.

        :param agent_assistant_id: The agent_assistant_id of this Call.
        :type: str
        """
        
        self._agent_assistant_id = agent_assistant_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CoachingAnnotation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CoachingAnnotation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'created_by': 'UserReference',
            'date_created': 'datetime',
            'modified_by': 'UserReference',
            'date_modified': 'datetime',
            'text': 'str',
            'is_deleted': 'bool',
            'access_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'created_by': 'createdBy',
            'date_created': 'dateCreated',
            'modified_by': 'modifiedBy',
            'date_modified': 'dateModified',
            'text': 'text',
            'is_deleted': 'isDeleted',
            'access_type': 'accessType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._created_by = None
        self._date_created = None
        self._modified_by = None
        self._date_modified = None
        self._text = None
        self._is_deleted = None
        self._access_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CoachingAnnotation.
        The globally unique identifier for the object.

        :return: The id of this CoachingAnnotation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CoachingAnnotation.
        The globally unique identifier for the object.

        :param id: The id of this CoachingAnnotation.
        :type: str
        """
        
        self._id = id

    @property
    def created_by(self):
        """
        Gets the created_by of this CoachingAnnotation.
        The user who created the annotation.

        :return: The created_by of this CoachingAnnotation.
        :rtype: UserReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this CoachingAnnotation.
        The user who created the annotation.

        :param created_by: The created_by of this CoachingAnnotation.
        :type: UserReference
        """
        
        self._created_by = created_by

    @property
    def date_created(self):
        """
        Gets the date_created of this CoachingAnnotation.
        The date/time the annotation was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this CoachingAnnotation.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CoachingAnnotation.
        The date/time the annotation was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this CoachingAnnotation.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def modified_by(self):
        """
        Gets the modified_by of this CoachingAnnotation.
        The last user to modify the annotation.

        :return: The modified_by of this CoachingAnnotation.
        :rtype: UserReference
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this CoachingAnnotation.
        The last user to modify the annotation.

        :param modified_by: The modified_by of this CoachingAnnotation.
        :type: UserReference
        """
        
        self._modified_by = modified_by

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CoachingAnnotation.
        The date/time the annotation was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this CoachingAnnotation.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CoachingAnnotation.
        The date/time the annotation was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this CoachingAnnotation.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def text(self):
        """
        Gets the text of this CoachingAnnotation.
        The text of the annotation.

        :return: The text of this CoachingAnnotation.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this CoachingAnnotation.
        The text of the annotation.

        :param text: The text of this CoachingAnnotation.
        :type: str
        """
        
        self._text = text

    @property
    def is_deleted(self):
        """
        Gets the is_deleted of this CoachingAnnotation.
        Flag indicating whether the annotation is deleted.

        :return: The is_deleted of this CoachingAnnotation.
        :rtype: bool
        """
        return self._is_deleted

    @is_deleted.setter
    def is_deleted(self, is_deleted):
        """
        Sets the is_deleted of this CoachingAnnotation.
        Flag indicating whether the annotation is deleted.

        :param is_deleted: The is_deleted of this CoachingAnnotation.
        :type: bool
        """
        
        self._is_deleted = is_deleted

    @property
    def access_type(self):
        """
        Gets the access_type of this CoachingAnnotation.
        Determines the permissions required to view this item.

        :return: The access_type of this CoachingAnnotation.
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """
        Sets the access_type of this CoachingAnnotation.
        Determines the permissions required to view this item.

        :param access_type: The access_type of this CoachingAnnotation.
        :type: str
        """
        allowed_values = ["Public", "Private"]
        if access_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for access_type -> " + access_type)
            self._access_type = "outdated_sdk_version"
        else:
            self._access_type = access_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CoachingAnnotation.
        The URI for this object

        :return: The self_uri of this CoachingAnnotation.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CoachingAnnotation.
        The URI for this object

        :param self_uri: The self_uri of this CoachingAnnotation.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EdgeLogsJobFile(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeLogsJobFile - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'time_created': 'datetime',
            'time_modified': 'datetime',
            'size_bytes': 'float',
            'upload_status': 'str',
            'edge_path': 'str',
            'download_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'time_created': 'timeCreated',
            'time_modified': 'timeModified',
            'size_bytes': 'sizeBytes',
            'upload_status': 'uploadStatus',
            'edge_path': 'edgePath',
            'download_id': 'downloadId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._time_created = None
        self._time_modified = None
        self._size_bytes = None
        self._upload_status = None
        self._edge_path = None
        self._download_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EdgeLogsJobFile.
        The globally unique identifier for the object.

        :return: The id of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EdgeLogsJobFile.
        The globally unique identifier for the object.

        :param id: The id of this EdgeLogsJobFile.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EdgeLogsJobFile.
        The name of the entity.

        :return: The name of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EdgeLogsJobFile.
        The name of the entity.

        :param name: The name of this EdgeLogsJobFile.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this EdgeLogsJobFile.
        The resource's description.

        :return: The description of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this EdgeLogsJobFile.
        The resource's description.

        :param description: The description of this EdgeLogsJobFile.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this EdgeLogsJobFile.
        The current version of the resource.

        :return: The version of this EdgeLogsJobFile.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this EdgeLogsJobFile.
        The current version of the resource.

        :param version: The version of this EdgeLogsJobFile.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this EdgeLogsJobFile.
        The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this EdgeLogsJobFile.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this EdgeLogsJobFile.
        The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this EdgeLogsJobFile.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this EdgeLogsJobFile.
        The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this EdgeLogsJobFile.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this EdgeLogsJobFile.
        The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this EdgeLogsJobFile.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this EdgeLogsJobFile.
        The ID of the user that last modified the resource.

        :return: The modified_by of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this EdgeLogsJobFile.
        The ID of the user that last modified the resource.

        :param modified_by: The modified_by of this EdgeLogsJobFile.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this EdgeLogsJobFile.
        The ID of the user that created the resource.

        :return: The created_by of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this EdgeLogsJobFile.
        The ID of the user that created the resource.

        :param created_by: The created_by of this EdgeLogsJobFile.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this EdgeLogsJobFile.
        Indicates if the resource is active, inactive, or deleted.

        :return: The state of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this EdgeLogsJobFile.
        Indicates if the resource is active, inactive, or deleted.

        :param state: The state of this EdgeLogsJobFile.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this EdgeLogsJobFile.
        The application that last modified the resource.

        :return: The modified_by_app of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this EdgeLogsJobFile.
        The application that last modified the resource.

        :param modified_by_app: The modified_by_app of this EdgeLogsJobFile.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this EdgeLogsJobFile.
        The application that created the resource.

        :return: The created_by_app of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this EdgeLogsJobFile.
        The application that created the resource.

        :param created_by_app: The created_by_app of this EdgeLogsJobFile.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def time_created(self):
        """
        Gets the time_created of this EdgeLogsJobFile.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The time_created of this EdgeLogsJobFile.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this EdgeLogsJobFile.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param time_created: The time_created of this EdgeLogsJobFile.
        :type: datetime
        """
        
        self._time_created = time_created

    @property
    def time_modified(self):
        """
        Gets the time_modified of this EdgeLogsJobFile.
        The time this log file was last modified on the Edge. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The time_modified of this EdgeLogsJobFile.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this EdgeLogsJobFile.
        The time this log file was last modified on the Edge. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param time_modified: The time_modified of this EdgeLogsJobFile.
        :type: datetime
        """
        
        self._time_modified = time_modified

    @property
    def size_bytes(self):
        """
        Gets the size_bytes of this EdgeLogsJobFile.
        The size of this file in bytes.

        :return: The size_bytes of this EdgeLogsJobFile.
        :rtype: float
        """
        return self._size_bytes

    @size_bytes.setter
    def size_bytes(self, size_bytes):
        """
        Sets the size_bytes of this EdgeLogsJobFile.
        The size of this file in bytes.

        :param size_bytes: The size_bytes of this EdgeLogsJobFile.
        :type: float
        """
        
        self._size_bytes = size_bytes

    @property
    def upload_status(self):
        """
        Gets the upload_status of this EdgeLogsJobFile.
        The status of the upload of this file from the Edge to the cloud.  Use /upload to start an upload.

        :return: The upload_status of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._upload_status

    @upload_status.setter
    def upload_status(self, upload_status):
        """
        Sets the upload_status of this EdgeLogsJobFile.
        The status of the upload of this file from the Edge to the cloud.  Use /upload to start an upload.

        :param upload_status: The upload_status of this EdgeLogsJobFile.
        :type: str
        """
        allowed_values = ["UPLOADING", "NOT_UPLOADED", "UPLOADED", "ERROR_ON_UPLOAD"]
        if upload_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for upload_status -> " + upload_status)
            self._upload_status = "outdated_sdk_version"
        else:
            self._upload_status = upload_status

    @property
    def edge_path(self):
        """
        Gets the edge_path of this EdgeLogsJobFile.
        The path of this file on the Edge.

        :return: The edge_path of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._edge_path

    @edge_path.setter
    def edge_path(self, edge_path):
        """
        Sets the edge_path of this EdgeLogsJobFile.
        The path of this file on the Edge.

        :param edge_path: The edge_path of this EdgeLogsJobFile.
        :type: str
        """
        
        self._edge_path = edge_path

    @property
    def download_id(self):
        """
        Gets the download_id of this EdgeLogsJobFile.
        The download ID to use with the downloads API.

        :return: The download_id of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._download_id

    @download_id.setter
    def download_id(self, download_id):
        """
        Sets the download_id of this EdgeLogsJobFile.
        The download ID to use with the downloads API.

        :param download_id: The download_id of this EdgeLogsJobFile.
        :type: str
        """
        
        self._download_id = download_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EdgeLogsJobFile.
        The URI for this object

        :return: The self_uri of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EdgeLogsJobFile.
        The URI for this object

        :param self_uri: The self_uri of this EdgeLogsJobFile.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class JsonNodeSearchResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        JsonNodeSearchResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'total': 'int',
            'page_count': 'int',
            'page_size': 'int',
            'page_number': 'int',
            'previous_page': 'str',
            'current_page': 'str',
            'next_page': 'str',
            'types': 'list[str]',
            'results': 'ArrayNode',
            'aggregations': 'ArrayNode'
        }

        self.attribute_map = {
            'total': 'total',
            'page_count': 'pageCount',
            'page_size': 'pageSize',
            'page_number': 'pageNumber',
            'previous_page': 'previousPage',
            'current_page': 'currentPage',
            'next_page': 'nextPage',
            'types': 'types',
            'results': 'results',
            'aggregations': 'aggregations'
        }

        self._total = None
        self._page_count = None
        self._page_size = None
        self._page_number = None
        self._previous_page = None
        self._current_page = None
        self._next_page = None
        self._types = None
        self._results = None
        self._aggregations = None

    @property
    def total(self):
        """
        Gets the total of this JsonNodeSearchResponse.
        The total number of results found

        :return: The total of this JsonNodeSearchResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this JsonNodeSearchResponse.
        The total number of results found

        :param total: The total of this JsonNodeSearchResponse.
        :type: int
        """
        
        self._total = total

    @property
    def page_count(self):
        """
        Gets the page_count of this JsonNodeSearchResponse.
        The total number of pages

        :return: The page_count of this JsonNodeSearchResponse.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this JsonNodeSearchResponse.
        The total number of pages

        :param page_count: The page_count of this JsonNodeSearchResponse.
        :type: int
        """
        
        self._page_count = page_count

    @property
    def page_size(self):
        """
        Gets the page_size of this JsonNodeSearchResponse.
        The current page size

        :return: The page_size of this JsonNodeSearchResponse.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this JsonNodeSearchResponse.
        The current page size

        :param page_size: The page_size of this JsonNodeSearchResponse.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_number(self):
        """
        Gets the page_number of this JsonNodeSearchResponse.
        The current page number

        :return: The page_number of this JsonNodeSearchResponse.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this JsonNodeSearchResponse.
        The current page number

        :param page_number: The page_number of this JsonNodeSearchResponse.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def previous_page(self):
        """
        Gets the previous_page of this JsonNodeSearchResponse.
        Q64 value for the previous page of results

        :return: The previous_page of this JsonNodeSearchResponse.
        :rtype: str
        """
        return self._previous_page

    @previous_page.setter
    def previous_page(self, previous_page):
        """
        Sets the previous_page of this JsonNodeSearchResponse.
        Q64 value for the previous page of results

        :param previous_page: The previous_page of this JsonNodeSearchResponse.
        :type: str
        """
        
        self._previous_page = previous_page

    @property
    def current_page(self):
        """
        Gets the current_page of this JsonNodeSearchResponse.
        Q64 value for the current page of results

        :return: The current_page of this JsonNodeSearchResponse.
        :rtype: str
        """
        return self._current_page

    @current_page.setter
    def current_page(self, current_page):
        """
        Sets the current_page of this JsonNodeSearchResponse.
        Q64 value for the current page of results

        :param current_page: The current_page of this JsonNodeSearchResponse.
        :type: str
        """
        
        self._current_page = current_page

    @property
    def next_page(self):
        """
        Gets the next_page of this JsonNodeSearchResponse.
        Q64 value for the next page of results

        :return: The next_page of this JsonNodeSearchResponse.
        :rtype: str
        """
        return self._next_page

    @next_page.setter
    def next_page(self, next_page):
        """
        Sets the next_page of this JsonNodeSearchResponse.
        Q64 value for the next page of results

        :param next_page: The next_page of this JsonNodeSearchResponse.
        :type: str
        """
        
        self._next_page = next_page

    @property
    def types(self):
        """
        Gets the types of this JsonNodeSearchResponse.
        Resource types the search was performed against

        :return: The types of this JsonNodeSearchResponse.
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """
        Sets the types of this JsonNodeSearchResponse.
        Resource types the search was performed against

        :param types: The types of this JsonNodeSearchResponse.
        :type: list[str]
        """
        
        self._types = types

    @property
    def results(self):
        """
        Gets the results of this JsonNodeSearchResponse.
        Search results

        :return: The results of this JsonNodeSearchResponse.
        :rtype: ArrayNode
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this JsonNodeSearchResponse.
        Search results

        :param results: The results of this JsonNodeSearchResponse.
        :type: ArrayNode
        """
        
        self._results = results

    @property
    def aggregations(self):
        """
        Gets the aggregations of this JsonNodeSearchResponse.


        :return: The aggregations of this JsonNodeSearchResponse.
        :rtype: ArrayNode
        """
        return self._aggregations

    @aggregations.setter
    def aggregations(self, aggregations):
        """
        Sets the aggregations of this JsonNodeSearchResponse.


        :param aggregations: The aggregations of this JsonNodeSearchResponse.
        :type: ArrayNode
        """
        
        self._aggregations = aggregations

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WebChatDeployment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WebChatDeployment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'authentication_required': 'bool',
            'authentication_url': 'str',
            'disabled': 'bool',
            'web_chat_config': 'WebChatConfig',
            'allowed_domains': 'list[str]',
            'flow': 'DomainEntityRef',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'authentication_required': 'authenticationRequired',
            'authentication_url': 'authenticationUrl',
            'disabled': 'disabled',
            'web_chat_config': 'webChatConfig',
            'allowed_domains': 'allowedDomains',
            'flow': 'flow',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._authentication_required = None
        self._authentication_url = None
        self._disabled = None
        self._web_chat_config = None
        self._allowed_domains = None
        self._flow = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WebChatDeployment.
        The globally unique identifier for the object.

        :return: The id of this WebChatDeployment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WebChatDeployment.
        The globally unique identifier for the object.

        :param id: The id of this WebChatDeployment.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WebChatDeployment.


        :return: The name of this WebChatDeployment.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WebChatDeployment.


        :param name: The name of this WebChatDeployment.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this WebChatDeployment.


        :return: The description of this WebChatDeployment.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WebChatDeployment.


        :param description: The description of this WebChatDeployment.
        :type: str
        """
        
        self._description = description

    @property
    def authentication_required(self):
        """
        Gets the authentication_required of this WebChatDeployment.


        :return: The authentication_required of this WebChatDeployment.
        :rtype: bool
        """
        return self._authentication_required

    @authentication_required.setter
    def authentication_required(self, authentication_required):
        """
        Sets the authentication_required of this WebChatDeployment.


        :param authentication_required: The authentication_required of this WebChatDeployment.
        :type: bool
        """
        
        self._authentication_required = authentication_required

    @property
    def authentication_url(self):
        """
        Gets the authentication_url of this WebChatDeployment.
        URL for third party service authenticating web chat clients. See https://github.com/MyPureCloud/authenticated-web-chat-server-examples

        :return: The authentication_url of this WebChatDeployment.
        :rtype: str
        """
        return self._authentication_url

    @authentication_url.setter
    def authentication_url(self, authentication_url):
        """
        Sets the authentication_url of this WebChatDeployment.
        URL for third party service authenticating web chat clients. See https://github.com/MyPureCloud/authenticated-web-chat-server-examples

        :param authentication_url: The authentication_url of this WebChatDeployment.
        :type: str
        """
        
        self._authentication_url = authentication_url

    @property
    def disabled(self):
        """
        Gets the disabled of this WebChatDeployment.


        :return: The disabled of this WebChatDeployment.
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """
        Sets the disabled of this WebChatDeployment.


        :param disabled: The disabled of this WebChatDeployment.
        :type: bool
        """
        
        self._disabled = disabled

    @property
    def web_chat_config(self):
        """
        Gets the web_chat_config of this WebChatDeployment.


        :return: The web_chat_config of this WebChatDeployment.
        :rtype: WebChatConfig
        """
        return self._web_chat_config

    @web_chat_config.setter
    def web_chat_config(self, web_chat_config):
        """
        Sets the web_chat_config of this WebChatDeployment.


        :param web_chat_config: The web_chat_config of this WebChatDeployment.
        :type: WebChatConfig
        """
        
        self._web_chat_config = web_chat_config

    @property
    def allowed_domains(self):
        """
        Gets the allowed_domains of this WebChatDeployment.


        :return: The allowed_domains of this WebChatDeployment.
        :rtype: list[str]
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        """
        Sets the allowed_domains of this WebChatDeployment.


        :param allowed_domains: The allowed_domains of this WebChatDeployment.
        :type: list[str]
        """
        
        self._allowed_domains = allowed_domains

    @property
    def flow(self):
        """
        Gets the flow of this WebChatDeployment.
        The URI of the Inbound Chat Flow to run when new chats are initiated under this Deployment.

        :return: The flow of this WebChatDeployment.
        :rtype: DomainEntityRef
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """
        Sets the flow of this WebChatDeployment.
        The URI of the Inbound Chat Flow to run when new chats are initiated under this Deployment.

        :param flow: The flow of this WebChatDeployment.
        :type: DomainEntityRef
        """
        
        self._flow = flow

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WebChatDeployment.
        The URI for this object

        :return: The self_uri of this WebChatDeployment.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WebChatDeployment.
        The URI for this object

        :param self_uri: The self_uri of this WebChatDeployment.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
BillingApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class BillingApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_billing_reports_billableusage(self, start_date, end_date, **kwargs):
        """
        Get a report of the billable license usages
        Report is of the billable usages (e.g. licenses and devices utilized) for a given period. If response's status is InProgress, wait a few seconds, then try the same request again.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_billing_reports_billableusage(start_date, end_date, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param datetime start_date: The period start date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z (required)
        :param datetime end_date: The period end date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z (required)
        :return: BillingUsageReport
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_date', 'end_date']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_reports_billableusage" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'start_date' is set
        if ('start_date' not in params) or (params['start_date'] is None):
            raise ValueError("Missing the required parameter `start_date` when calling `get_billing_reports_billableusage`")
        # verify the required parameter 'end_date' is set
        if ('end_date' not in params) or (params['end_date'] is None):
            raise ValueError("Missing the required parameter `end_date` when calling `get_billing_reports_billableusage`")


        resource_path = '/api/v2/billing/reports/billableusage'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'start_date' in params:
            query_params['startDate'] = params['start_date']
        if 'end_date' in params:
            query_params['endDate'] = params['end_date']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='BillingUsageReport',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_billing_trusteebillingoverview_trustor_org_id(self, trustor_org_id, **kwargs):
        """
        Get the billing overview for an organization that is managed by a partner.
        Tax Disclaimer: Prices returned by this API do not include applicable taxes. It is the responsibility of the customer to pay all taxes that are appropriate in their jurisdiction. See the PureCloud API Documentation in the Developer Center for more information about this API: https://developer.mypurecloud.com/api/rest/v2/

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_billing_trusteebillingoverview_trustor_org_id(trustor_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: The organization ID of the trustor (customer) organization. (required)
        :param int billing_period_index: 0 for active period (overview data may change until period closes). 1 for prior completed billing period. 2 for two billing cycles prior, and so on.
        :return: TrusteeBillingOverview
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id', 'billing_period_index']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_trusteebillingoverview_trustor_org_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `get_billing_trusteebillingoverview_trustor_org_id`")


        resource_path = '/api/v2/billing/trusteebillingoverview/{trustorOrgId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']

        query_params = {}
        if 'billing_period_index' in params:
            query_params['billingPeriodIndex'] = params['billing_period_index']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrusteeBillingOverview',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerDnclistConfigChangeDncList(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerDnclistConfigChangeDncList - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'import_status': 'DialerDnclistConfigChangeImportStatus',
            'size': 'int',
            'dnc_source_type': 'str',
            'login_id': 'str',
            'dnc_codes': 'list[str]',
            'license_id': 'str',
            'division': 'DialerDnclistConfigChangeUriReference',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'import_status': 'importStatus',
            'size': 'size',
            'dnc_source_type': 'dncSourceType',
            'login_id': 'loginId',
            'dnc_codes': 'dncCodes',
            'license_id': 'licenseId',
            'division': 'division',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._import_status = None
        self._size = None
        self._dnc_source_type = None
        self._login_id = None
        self._dnc_codes = None
        self._license_id = None
        self._division = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this DialerDnclistConfigChangeDncList.


        :return: The id of this DialerDnclistConfigChangeDncList.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerDnclistConfigChangeDncList.


        :param id: The id of this DialerDnclistConfigChangeDncList.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerDnclistConfigChangeDncList.


        :return: The name of this DialerDnclistConfigChangeDncList.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerDnclistConfigChangeDncList.


        :param name: The name of this DialerDnclistConfigChangeDncList.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this DialerDnclistConfigChangeDncList.


        :return: The date_created of this DialerDnclistConfigChangeDncList.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DialerDnclistConfigChangeDncList.


        :param date_created: The date_created of this DialerDnclistConfigChangeDncList.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DialerDnclistConfigChangeDncList.


        :return: The date_modified of this DialerDnclistConfigChangeDncList.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DialerDnclistConfigChangeDncList.


        :param date_modified: The date_modified of this DialerDnclistConfigChangeDncList.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this DialerDnclistConfigChangeDncList.


        :return: The version of this DialerDnclistConfigChangeDncList.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DialerDnclistConfigChangeDncList.


        :param version: The version of this DialerDnclistConfigChangeDncList.
        :type: int
        """
        
        self._version = version

    @property
    def import_status(self):
        """
        Gets the import_status of this DialerDnclistConfigChangeDncList.


        :return: The import_status of this DialerDnclistConfigChangeDncList.
        :rtype: DialerDnclistConfigChangeImportStatus
        """
        return self._import_status

    @import_status.setter
    def import_status(self, import_status):
        """
        Sets the import_status of this DialerDnclistConfigChangeDncList.


        :param import_status: The import_status of this DialerDnclistConfigChangeDncList.
        :type: DialerDnclistConfigChangeImportStatus
        """
        
        self._import_status = import_status

    @property
    def size(self):
        """
        Gets the size of this DialerDnclistConfigChangeDncList.


        :return: The size of this DialerDnclistConfigChangeDncList.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this DialerDnclistConfigChangeDncList.


        :param size: The size of this DialerDnclistConfigChangeDncList.
        :type: int
        """
        
        self._size = size

    @property
    def dnc_source_type(self):
        """
        Gets the dnc_source_type of this DialerDnclistConfigChangeDncList.


        :return: The dnc_source_type of this DialerDnclistConfigChangeDncList.
        :rtype: str
        """
        return self._dnc_source_type

    @dnc_source_type.setter
    def dnc_source_type(self, dnc_source_type):
        """
        Sets the dnc_source_type of this DialerDnclistConfigChangeDncList.


        :param dnc_source_type: The dnc_source_type of this DialerDnclistConfigChangeDncList.
        :type: str
        """
        allowed_values = ["RDS", "DNC_COM", "GRYPHON"]
        if dnc_source_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for dnc_source_type -> " + dnc_source_type)
            self._dnc_source_type = "outdated_sdk_version"
        else:
            self._dnc_source_type = dnc_source_type

    @property
    def login_id(self):
        """
        Gets the login_id of this DialerDnclistConfigChangeDncList.


        :return: The login_id of this DialerDnclistConfigChangeDncList.
        :rtype: str
        """
        return self._login_id

    @login_id.setter
    def login_id(self, login_id):
        """
        Sets the login_id of this DialerDnclistConfigChangeDncList.


        :param login_id: The login_id of this DialerDnclistConfigChangeDncList.
        :type: str
        """
        
        self._login_id = login_id

    @property
    def dnc_codes(self):
        """
        Gets the dnc_codes of this DialerDnclistConfigChangeDncList.


        :return: The dnc_codes of this DialerDnclistConfigChangeDncList.
        :rtype: list[str]
        """
        return self._dnc_codes

    @dnc_codes.setter
    def dnc_codes(self, dnc_codes):
        """
        Sets the dnc_codes of this DialerDnclistConfigChangeDncList.


        :param dnc_codes: The dnc_codes of this DialerDnclistConfigChangeDncList.
        :type: list[str]
        """
        
        self._dnc_codes = dnc_codes

    @property
    def license_id(self):
        """
        Gets the license_id of this DialerDnclistConfigChangeDncList.


        :return: The license_id of this DialerDnclistConfigChangeDncList.
        :rtype: str
        """
        return self._license_id

    @license_id.setter
    def license_id(self, license_id):
        """
        Sets the license_id of this DialerDnclistConfigChangeDncList.


        :param license_id: The license_id of this DialerDnclistConfigChangeDncList.
        :type: str
        """
        
        self._license_id = license_id

    @property
    def division(self):
        """
        Gets the division of this DialerDnclistConfigChangeDncList.


        :return: The division of this DialerDnclistConfigChangeDncList.
        :rtype: DialerDnclistConfigChangeUriReference
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this DialerDnclistConfigChangeDncList.


        :param division: The division of this DialerDnclistConfigChangeDncList.
        :type: DialerDnclistConfigChangeUriReference
        """
        
        self._division = division

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerDnclistConfigChangeDncList.


        :return: The additional_properties of this DialerDnclistConfigChangeDncList.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerDnclistConfigChangeDncList.


        :param additional_properties: The additional_properties of this DialerDnclistConfigChangeDncList.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WeekScheduleListItemResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WeekScheduleListItemResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'self_uri': 'str',
            'week_date': 'str',
            'description': 'str',
            'published': 'bool',
            'generation_results': 'WeekScheduleGenerationResult',
            'short_term_forecast': 'ShortTermForecastReference',
            'metadata': 'WfmVersionedEntityMetadata'
        }

        self.attribute_map = {
            'id': 'id',
            'self_uri': 'selfUri',
            'week_date': 'weekDate',
            'description': 'description',
            'published': 'published',
            'generation_results': 'generationResults',
            'short_term_forecast': 'shortTermForecast',
            'metadata': 'metadata'
        }

        self._id = None
        self._self_uri = None
        self._week_date = None
        self._description = None
        self._published = None
        self._generation_results = None
        self._short_term_forecast = None
        self._metadata = None

    @property
    def id(self):
        """
        Gets the id of this WeekScheduleListItemResponse.
        The globally unique identifier for the object.

        :return: The id of this WeekScheduleListItemResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WeekScheduleListItemResponse.
        The globally unique identifier for the object.

        :param id: The id of this WeekScheduleListItemResponse.
        :type: str
        """
        
        self._id = id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WeekScheduleListItemResponse.
        The URI for this object

        :return: The self_uri of this WeekScheduleListItemResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WeekScheduleListItemResponse.
        The URI for this object

        :param self_uri: The self_uri of this WeekScheduleListItemResponse.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def week_date(self):
        """
        Gets the week_date of this WeekScheduleListItemResponse.
        First day of this week schedule in yyyy-MM-dd format

        :return: The week_date of this WeekScheduleListItemResponse.
        :rtype: str
        """
        return self._week_date

    @week_date.setter
    def week_date(self, week_date):
        """
        Sets the week_date of this WeekScheduleListItemResponse.
        First day of this week schedule in yyyy-MM-dd format

        :param week_date: The week_date of this WeekScheduleListItemResponse.
        :type: str
        """
        
        self._week_date = week_date

    @property
    def description(self):
        """
        Gets the description of this WeekScheduleListItemResponse.
        Description of the week schedule

        :return: The description of this WeekScheduleListItemResponse.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WeekScheduleListItemResponse.
        Description of the week schedule

        :param description: The description of this WeekScheduleListItemResponse.
        :type: str
        """
        
        self._description = description

    @property
    def published(self):
        """
        Gets the published of this WeekScheduleListItemResponse.
        Whether the week schedule is published

        :return: The published of this WeekScheduleListItemResponse.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this WeekScheduleListItemResponse.
        Whether the week schedule is published

        :param published: The published of this WeekScheduleListItemResponse.
        :type: bool
        """
        
        self._published = published

    @property
    def generation_results(self):
        """
        Gets the generation_results of this WeekScheduleListItemResponse.
        Summary of the results from the schedule run

        :return: The generation_results of this WeekScheduleListItemResponse.
        :rtype: WeekScheduleGenerationResult
        """
        return self._generation_results

    @generation_results.setter
    def generation_results(self, generation_results):
        """
        Sets the generation_results of this WeekScheduleListItemResponse.
        Summary of the results from the schedule run

        :param generation_results: The generation_results of this WeekScheduleListItemResponse.
        :type: WeekScheduleGenerationResult
        """
        
        self._generation_results = generation_results

    @property
    def short_term_forecast(self):
        """
        Gets the short_term_forecast of this WeekScheduleListItemResponse.
        Short term forecast associated with this schedule

        :return: The short_term_forecast of this WeekScheduleListItemResponse.
        :rtype: ShortTermForecastReference
        """
        return self._short_term_forecast

    @short_term_forecast.setter
    def short_term_forecast(self, short_term_forecast):
        """
        Sets the short_term_forecast of this WeekScheduleListItemResponse.
        Short term forecast associated with this schedule

        :param short_term_forecast: The short_term_forecast of this WeekScheduleListItemResponse.
        :type: ShortTermForecastReference
        """
        
        self._short_term_forecast = short_term_forecast

    @property
    def metadata(self):
        """
        Gets the metadata of this WeekScheduleListItemResponse.
        Version metadata for this work plan

        :return: The metadata of this WeekScheduleListItemResponse.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this WeekScheduleListItemResponse.
        Version metadata for this work plan

        :param metadata: The metadata of this WeekScheduleListItemResponse.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class JourneyAggregationQuery(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        JourneyAggregationQuery - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'interval': 'str',
            'granularity': 'str',
            'time_zone': 'str',
            'group_by': 'list[str]',
            'filter': 'JourneyAggregateQueryFilter',
            'metrics': 'list[str]',
            'flatten_multivalued_dimensions': 'bool',
            'views': 'list[JourneyAggregationView]',
            'alternate_time_dimension': 'str'
        }

        self.attribute_map = {
            'interval': 'interval',
            'granularity': 'granularity',
            'time_zone': 'timeZone',
            'group_by': 'groupBy',
            'filter': 'filter',
            'metrics': 'metrics',
            'flatten_multivalued_dimensions': 'flattenMultivaluedDimensions',
            'views': 'views',
            'alternate_time_dimension': 'alternateTimeDimension'
        }

        self._interval = None
        self._granularity = None
        self._time_zone = None
        self._group_by = None
        self._filter = None
        self._metrics = None
        self._flatten_multivalued_dimensions = None
        self._views = None
        self._alternate_time_dimension = None

    @property
    def interval(self):
        """
        Gets the interval of this JourneyAggregationQuery.
        Behaves like one clause in a SQL WHERE. Specifies the date and time range of data being queried. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this JourneyAggregationQuery.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this JourneyAggregationQuery.
        Behaves like one clause in a SQL WHERE. Specifies the date and time range of data being queried. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this JourneyAggregationQuery.
        :type: str
        """
        
        self._interval = interval

    @property
    def granularity(self):
        """
        Gets the granularity of this JourneyAggregationQuery.
        Granularity aggregates metrics into subpartitions within the time interval specified. The default granularity is the same duration as the interval. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H

        :return: The granularity of this JourneyAggregationQuery.
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """
        Sets the granularity of this JourneyAggregationQuery.
        Granularity aggregates metrics into subpartitions within the time interval specified. The default granularity is the same duration as the interval. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H

        :param granularity: The granularity of this JourneyAggregationQuery.
        :type: str
        """
        
        self._granularity = granularity

    @property
    def time_zone(self):
        """
        Gets the time_zone of this JourneyAggregationQuery.
        Time zone context used to calculate response intervals (this allows resolving DST changes). The interval offset is used even when timeZone is specified. Default is UTC. Time zones are represented as a string of the zone name as found in the IANA time zone database. For example: UTC, Etc/UTC, or Europe/London

        :return: The time_zone of this JourneyAggregationQuery.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this JourneyAggregationQuery.
        Time zone context used to calculate response intervals (this allows resolving DST changes). The interval offset is used even when timeZone is specified. Default is UTC. Time zones are represented as a string of the zone name as found in the IANA time zone database. For example: UTC, Etc/UTC, or Europe/London

        :param time_zone: The time_zone of this JourneyAggregationQuery.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def group_by(self):
        """
        Gets the group_by of this JourneyAggregationQuery.
        Behaves like a SQL GROUPBY. Allows for multiple levels of grouping as a list of dimensions. Partitions resulting aggregate computations into distinct named subgroups rather than across the entire result set as if it were one group.

        :return: The group_by of this JourneyAggregationQuery.
        :rtype: list[str]
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """
        Sets the group_by of this JourneyAggregationQuery.
        Behaves like a SQL GROUPBY. Allows for multiple levels of grouping as a list of dimensions. Partitions resulting aggregate computations into distinct named subgroups rather than across the entire result set as if it were one group.

        :param group_by: The group_by of this JourneyAggregationQuery.
        :type: list[str]
        """
        
        self._group_by = group_by

    @property
    def filter(self):
        """
        Gets the filter of this JourneyAggregationQuery.
        Behaves like a SQL WHERE clause. This is ANDed with the interval parameter. Expresses boolean logical predicates as well as dimensional filters

        :return: The filter of this JourneyAggregationQuery.
        :rtype: JourneyAggregateQueryFilter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this JourneyAggregationQuery.
        Behaves like a SQL WHERE clause. This is ANDed with the interval parameter. Expresses boolean logical predicates as well as dimensional filters

        :param filter: The filter of this JourneyAggregationQuery.
        :type: JourneyAggregateQueryFilter
        """
        
        self._filter = filter

    @property
    def metrics(self):
        """
        Gets the metrics of this JourneyAggregationQuery.
        Behaves like a SQL SELECT clause. Only named metrics will be retrieved.

        :return: The metrics of this JourneyAggregationQuery.
        :rtype: list[str]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this JourneyAggregationQuery.
        Behaves like a SQL SELECT clause. Only named metrics will be retrieved.

        :param metrics: The metrics of this JourneyAggregationQuery.
        :type: list[str]
        """
        
        self._metrics = metrics

    @property
    def flatten_multivalued_dimensions(self):
        """
        Gets the flatten_multivalued_dimensions of this JourneyAggregationQuery.
        Flattens any multivalued dimensions used in response groups (e.g. ['a','b','c']->'a,b,c')

        :return: The flatten_multivalued_dimensions of this JourneyAggregationQuery.
        :rtype: bool
        """
        return self._flatten_multivalued_dimensions

    @flatten_multivalued_dimensions.setter
    def flatten_multivalued_dimensions(self, flatten_multivalued_dimensions):
        """
        Sets the flatten_multivalued_dimensions of this JourneyAggregationQuery.
        Flattens any multivalued dimensions used in response groups (e.g. ['a','b','c']->'a,b,c')

        :param flatten_multivalued_dimensions: The flatten_multivalued_dimensions of this JourneyAggregationQuery.
        :type: bool
        """
        
        self._flatten_multivalued_dimensions = flatten_multivalued_dimensions

    @property
    def views(self):
        """
        Gets the views of this JourneyAggregationQuery.
        Custom derived metric views

        :return: The views of this JourneyAggregationQuery.
        :rtype: list[JourneyAggregationView]
        """
        return self._views

    @views.setter
    def views(self, views):
        """
        Sets the views of this JourneyAggregationQuery.
        Custom derived metric views

        :param views: The views of this JourneyAggregationQuery.
        :type: list[JourneyAggregationView]
        """
        
        self._views = views

    @property
    def alternate_time_dimension(self):
        """
        Gets the alternate_time_dimension of this JourneyAggregationQuery.
        Dimension to use as the alternative timestamp for data in the aggregate.  Choosing \"eventTime\" uses the actual time of the data event.

        :return: The alternate_time_dimension of this JourneyAggregationQuery.
        :rtype: str
        """
        return self._alternate_time_dimension

    @alternate_time_dimension.setter
    def alternate_time_dimension(self, alternate_time_dimension):
        """
        Sets the alternate_time_dimension of this JourneyAggregationQuery.
        Dimension to use as the alternative timestamp for data in the aggregate.  Choosing \"eventTime\" uses the actual time of the data event.

        :param alternate_time_dimension: The alternate_time_dimension of this JourneyAggregationQuery.
        :type: str
        """
        allowed_values = ["eventTime"]
        if alternate_time_dimension.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for alternate_time_dimension -> " + alternate_time_dimension)
            self._alternate_time_dimension = "outdated_sdk_version"
        else:
            self._alternate_time_dimension = alternate_time_dimension

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SearchShiftTradesRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SearchShiftTradesRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'receiving_schedule_id': 'str',
            'receiving_shift_ids': 'list[str]'
        }

        self.attribute_map = {
            'receiving_schedule_id': 'receivingScheduleId',
            'receiving_shift_ids': 'receivingShiftIds'
        }

        self._receiving_schedule_id = None
        self._receiving_shift_ids = None

    @property
    def receiving_schedule_id(self):
        """
        Gets the receiving_schedule_id of this SearchShiftTradesRequest.
        The ID of the schedule for which to search for available shift trades

        :return: The receiving_schedule_id of this SearchShiftTradesRequest.
        :rtype: str
        """
        return self._receiving_schedule_id

    @receiving_schedule_id.setter
    def receiving_schedule_id(self, receiving_schedule_id):
        """
        Sets the receiving_schedule_id of this SearchShiftTradesRequest.
        The ID of the schedule for which to search for available shift trades

        :param receiving_schedule_id: The receiving_schedule_id of this SearchShiftTradesRequest.
        :type: str
        """
        
        self._receiving_schedule_id = receiving_schedule_id

    @property
    def receiving_shift_ids(self):
        """
        Gets the receiving_shift_ids of this SearchShiftTradesRequest.
        The IDs of shifts that the receiving user would potentially be willing to trade. If empty, only returns one sided trades (pick up a shift)

        :return: The receiving_shift_ids of this SearchShiftTradesRequest.
        :rtype: list[str]
        """
        return self._receiving_shift_ids

    @receiving_shift_ids.setter
    def receiving_shift_ids(self, receiving_shift_ids):
        """
        Sets the receiving_shift_ids of this SearchShiftTradesRequest.
        The IDs of shifts that the receiving user would potentially be willing to trade. If empty, only returns one sided trades (pick up a shift)

        :param receiving_shift_ids: The receiving_shift_ids of this SearchShiftTradesRequest.
        :type: list[str]
        """
        
        self._receiving_shift_ids = receiving_shift_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmBuShortTermForecastImportCompleteTopicBuForecastModification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmBuShortTermForecastImportCompleteTopicBuForecastModification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'start_interval_index': 'int',
            'end_interval_index': 'int',
            'metric': 'str',
            'legacy_metric': 'str',
            'value': 'float',
            'values': 'list[WfmBuShortTermForecastImportCompleteTopicModificationIntervalOffsetValue]',
            'enabled': 'bool',
            'granularity': 'str',
            'display_granularity': 'str',
            'planning_group_ids': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'start_interval_index': 'startIntervalIndex',
            'end_interval_index': 'endIntervalIndex',
            'metric': 'metric',
            'legacy_metric': 'legacyMetric',
            'value': 'value',
            'values': 'values',
            'enabled': 'enabled',
            'granularity': 'granularity',
            'display_granularity': 'displayGranularity',
            'planning_group_ids': 'planningGroupIds'
        }

        self._type = None
        self._start_interval_index = None
        self._end_interval_index = None
        self._metric = None
        self._legacy_metric = None
        self._value = None
        self._values = None
        self._enabled = None
        self._granularity = None
        self._display_granularity = None
        self._planning_group_ids = None

    @property
    def type(self):
        """
        Gets the type of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The type of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param type: The type of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: str
        """
        allowed_values = ["MinimumPerInterval", "MaximumPerInterval", "SetValuePerInterval", "ChangeValuePerInterval", "ChangePercentPerInterval", "SetValueOverRange", "ChangeValueOverRange", "SetValuesForIntervalSet"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def start_interval_index(self):
        """
        Gets the start_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The start_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: int
        """
        return self._start_interval_index

    @start_interval_index.setter
    def start_interval_index(self, start_interval_index):
        """
        Sets the start_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param start_interval_index: The start_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: int
        """
        
        self._start_interval_index = start_interval_index

    @property
    def end_interval_index(self):
        """
        Gets the end_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The end_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: int
        """
        return self._end_interval_index

    @end_interval_index.setter
    def end_interval_index(self, end_interval_index):
        """
        Sets the end_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param end_interval_index: The end_interval_index of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: int
        """
        
        self._end_interval_index = end_interval_index

    @property
    def metric(self):
        """
        Gets the metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param metric: The metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: str
        """
        allowed_values = ["Offered", "AverageHandleTimeSeconds"]
        if metric.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for metric -> " + metric)
            self._metric = "outdated_sdk_version"
        else:
            self._metric = metric

    @property
    def legacy_metric(self):
        """
        Gets the legacy_metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The legacy_metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: str
        """
        return self._legacy_metric

    @legacy_metric.setter
    def legacy_metric(self, legacy_metric):
        """
        Sets the legacy_metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param legacy_metric: The legacy_metric of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: str
        """
        allowed_values = ["AverageAfterCallWorkTimeSeconds", "AverageHandleTimeSeconds", "AverageTalkTimeSeconds", "Offered"]
        if legacy_metric.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for legacy_metric -> " + legacy_metric)
            self._legacy_metric = "outdated_sdk_version"
        else:
            self._legacy_metric = legacy_metric

    @property
    def value(self):
        """
        Gets the value of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The value of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param value: The value of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: float
        """
        
        self._value = value

    @property
    def values(self):
        """
        Gets the values of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The values of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: list[WfmBuShortTermForecastImportCompleteTopicModificationIntervalOffsetValue]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param values: The values of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: list[WfmBuShortTermForecastImportCompleteTopicModificationIntervalOffsetValue]
        """
        
        self._values = values

    @property
    def enabled(self):
        """
        Gets the enabled of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The enabled of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param enabled: The enabled of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def granularity(self):
        """
        Gets the granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """
        Sets the granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param granularity: The granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: str
        """
        
        self._granularity = granularity

    @property
    def display_granularity(self):
        """
        Gets the display_granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The display_granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: str
        """
        return self._display_granularity

    @display_granularity.setter
    def display_granularity(self, display_granularity):
        """
        Sets the display_granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param display_granularity: The display_granularity of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: str
        """
        
        self._display_granularity = display_granularity

    @property
    def planning_group_ids(self):
        """
        Gets the planning_group_ids of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :return: The planning_group_ids of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :rtype: list[str]
        """
        return self._planning_group_ids

    @planning_group_ids.setter
    def planning_group_ids(self, planning_group_ids):
        """
        Sets the planning_group_ids of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.


        :param planning_group_ids: The planning_group_ids of this WfmBuShortTermForecastImportCompleteTopicBuForecastModification.
        :type: list[str]
        """
        
        self._planning_group_ids = planning_group_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ReportingExportJobRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ReportingExportJobRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'time_zone': 'str',
            'export_format': 'str',
            'interval': 'str',
            'period': 'str',
            'view_type': 'str',
            'filter': 'ViewFilter',
            'read': 'bool',
            'locale': 'str',
            'has_format_durations': 'bool',
            'has_split_filters': 'bool',
            'exclude_empty_rows': 'bool',
            'has_split_by_media': 'bool',
            'has_summary_row': 'bool',
            'csv_delimiter': 'str',
            'selected_columns': 'list[SelectedColumns]',
            'has_custom_participant_attributes': 'bool',
            'recipient_emails': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'time_zone': 'timeZone',
            'export_format': 'exportFormat',
            'interval': 'interval',
            'period': 'period',
            'view_type': 'viewType',
            'filter': 'filter',
            'read': 'read',
            'locale': 'locale',
            'has_format_durations': 'hasFormatDurations',
            'has_split_filters': 'hasSplitFilters',
            'exclude_empty_rows': 'excludeEmptyRows',
            'has_split_by_media': 'hasSplitByMedia',
            'has_summary_row': 'hasSummaryRow',
            'csv_delimiter': 'csvDelimiter',
            'selected_columns': 'selectedColumns',
            'has_custom_participant_attributes': 'hasCustomParticipantAttributes',
            'recipient_emails': 'recipientEmails'
        }

        self._name = None
        self._time_zone = None
        self._export_format = None
        self._interval = None
        self._period = None
        self._view_type = None
        self._filter = None
        self._read = None
        self._locale = None
        self._has_format_durations = None
        self._has_split_filters = None
        self._exclude_empty_rows = None
        self._has_split_by_media = None
        self._has_summary_row = None
        self._csv_delimiter = None
        self._selected_columns = None
        self._has_custom_participant_attributes = None
        self._recipient_emails = None

    @property
    def name(self):
        """
        Gets the name of this ReportingExportJobRequest.
        The user supplied name of the export request

        :return: The name of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReportingExportJobRequest.
        The user supplied name of the export request

        :param name: The name of this ReportingExportJobRequest.
        :type: str
        """
        
        self._name = name

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ReportingExportJobRequest.
        The requested timezone of the exported data. Time zones are represented as a string of the zone name as found in the IANA time zone database. For example: UTC, Etc/UTC, or Europe/London

        :return: The time_zone of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ReportingExportJobRequest.
        The requested timezone of the exported data. Time zones are represented as a string of the zone name as found in the IANA time zone database. For example: UTC, Etc/UTC, or Europe/London

        :param time_zone: The time_zone of this ReportingExportJobRequest.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def export_format(self):
        """
        Gets the export_format of this ReportingExportJobRequest.
        The requested format of the exported data

        :return: The export_format of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._export_format

    @export_format.setter
    def export_format(self, export_format):
        """
        Sets the export_format of this ReportingExportJobRequest.
        The requested format of the exported data

        :param export_format: The export_format of this ReportingExportJobRequest.
        :type: str
        """
        allowed_values = ["CSV", "PDF"]
        if export_format.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for export_format -> " + export_format)
            self._export_format = "outdated_sdk_version"
        else:
            self._export_format = export_format

    @property
    def interval(self):
        """
        Gets the interval of this ReportingExportJobRequest.
        The time period used to limit the the exported data. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this ReportingExportJobRequest.
        The time period used to limit the the exported data. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this ReportingExportJobRequest.
        :type: str
        """
        
        self._interval = interval

    @property
    def period(self):
        """
        Gets the period of this ReportingExportJobRequest.
        The Period of the request in which to break down the intervals. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H

        :return: The period of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """
        Sets the period of this ReportingExportJobRequest.
        The Period of the request in which to break down the intervals. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H

        :param period: The period of this ReportingExportJobRequest.
        :type: str
        """
        
        self._period = period

    @property
    def view_type(self):
        """
        Gets the view_type of this ReportingExportJobRequest.
        The type of view export job to be created

        :return: The view_type of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._view_type

    @view_type.setter
    def view_type(self, view_type):
        """
        Sets the view_type of this ReportingExportJobRequest.
        The type of view export job to be created

        :param view_type: The view_type of this ReportingExportJobRequest.
        :type: str
        """
        allowed_values = ["QUEUE_PERFORMANCE_SUMMARY_VIEW", "QUEUE_PERFORMANCE_DETAIL_VIEW", "INTERACTION_SEARCH_VIEW", "AGENT_PERFORMANCE_SUMMARY_VIEW", "AGENT_PERFORMANCE_DETAIL_VIEW", "AGENT_STATUS_SUMMARY_VIEW", "AGENT_STATUS_DETAIL_VIEW", "AGENT_EVALUATION_SUMMARY_VIEW", "AGENT_EVALUATION_DETAIL_VIEW", "AGENT_QUEUE_DETAIL_VIEW", "AGENT_INTERACTION_DETAIL_VIEW", "ABANDON_INSIGHTS_VIEW", "SKILLS_PERFORMANCE_VIEW", "SURVEY_FORM_PERFORMANCE_SUMMARY_VIEW", "SURVEY_FORM_PERFORMANCE_DETAIL_VIEW", "DNIS_PERFORMANCE_SUMMARY_VIEW", "DNIS_PERFORMANCE_DETAIL_VIEW", "WRAP_UP_PERFORMANCE_SUMMARY_VIEW", "AGENT_WRAP_UP_PERFORMANCE_DETAIL_VIEW", "QUEUE_ACTIVITY_SUMMARY_VIEW", "QUEUE_ACTIVITY_DETAIL_VIEW", "AGENT_QUEUE_ACTIVITY_SUMMARY_VIEW", "QUEUE_AGENT_DETAIL_VIEW", "QUEUE_INTERACTION_DETAIL_VIEW", "AGENT_SCHEDULE_DETAIL_VIEW", "IVR_PERFORMANCE_SUMMARY_VIEW", "IVR_PERFORMANCE_DETAIL_VIEW", "ANSWER_INSIGHTS_VIEW", "HANDLE_INSIGHTS_VIEW", "TALK_INSIGHTS_VIEW", "HOLD_INSIGHTS_VIEW", "ACW_INSIGHTS_VIEW", "WAIT_INSIGHTS_VIEW", "AGENT_WRAP_UP_PERFORMANCE_INTERVAL_DETAIL_VIEW", "FLOW_OUTCOME_SUMMARY_VIEW", "FLOW_OUTCOME_PERFORMANCE_DETAIL_VIEW", "FLOW_OUTCOME_PERFORMANCE_INTERVAL_DETAIL_VIEW", "FLOW_DESTINATION_SUMMARY_VIEW", "FLOW_DESTINATION_DETAIL_VIEW", "API_USAGE_VIEW", "SCHEDULED_CALLBACKS_VIEW", "CONTENT_SEARCH_VIEW", "LANDING_PAGE", "DASHBOARD_SUMMARY", "DASHBOARD_DETAIL", "JOURNEY_ACTION_MAP_SUMMARY_VIEW", "JOURNEY_OUTCOME_SUMMARY_VIEW", "JOURNEY_SEGMENT_SUMMARY_VIEW", "AGENT_DEVELOPMENT_DETAIL_VIEW", "AGENT_DEVELOPMENT_DETAIL_ME_VIEW", "AGENT_DEVELOPMENT_SUMMARY_VIEW", "AGENT_PERFORMANCE_ME_VIEW", "AGENT_STATUS_ME_VIEW", "AGENT_EVALUATION_ME_VIEW"]
        if view_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for view_type -> " + view_type)
            self._view_type = "outdated_sdk_version"
        else:
            self._view_type = view_type

    @property
    def filter(self):
        """
        Gets the filter of this ReportingExportJobRequest.
        Filters to apply to create the view

        :return: The filter of this ReportingExportJobRequest.
        :rtype: ViewFilter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this ReportingExportJobRequest.
        Filters to apply to create the view

        :param filter: The filter of this ReportingExportJobRequest.
        :type: ViewFilter
        """
        
        self._filter = filter

    @property
    def read(self):
        """
        Gets the read of this ReportingExportJobRequest.
        Indicates if the request has been marked as read

        :return: The read of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this ReportingExportJobRequest.
        Indicates if the request has been marked as read

        :param read: The read of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._read = read

    @property
    def locale(self):
        """
        Gets the locale of this ReportingExportJobRequest.
        The locale use for localization of the exported data, i.e. en-us, es-mx  

        :return: The locale of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """
        Sets the locale of this ReportingExportJobRequest.
        The locale use for localization of the exported data, i.e. en-us, es-mx  

        :param locale: The locale of this ReportingExportJobRequest.
        :type: str
        """
        
        self._locale = locale

    @property
    def has_format_durations(self):
        """
        Gets the has_format_durations of this ReportingExportJobRequest.
        Indicates if durations are formatted in hh:mm:ss format instead of ms

        :return: The has_format_durations of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._has_format_durations

    @has_format_durations.setter
    def has_format_durations(self, has_format_durations):
        """
        Sets the has_format_durations of this ReportingExportJobRequest.
        Indicates if durations are formatted in hh:mm:ss format instead of ms

        :param has_format_durations: The has_format_durations of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._has_format_durations = has_format_durations

    @property
    def has_split_filters(self):
        """
        Gets the has_split_filters of this ReportingExportJobRequest.
        Indicates if filters will be split in aggregate detail exports

        :return: The has_split_filters of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._has_split_filters

    @has_split_filters.setter
    def has_split_filters(self, has_split_filters):
        """
        Sets the has_split_filters of this ReportingExportJobRequest.
        Indicates if filters will be split in aggregate detail exports

        :param has_split_filters: The has_split_filters of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._has_split_filters = has_split_filters

    @property
    def exclude_empty_rows(self):
        """
        Gets the exclude_empty_rows of this ReportingExportJobRequest.
        Excludes empty rows from the exports

        :return: The exclude_empty_rows of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._exclude_empty_rows

    @exclude_empty_rows.setter
    def exclude_empty_rows(self, exclude_empty_rows):
        """
        Sets the exclude_empty_rows of this ReportingExportJobRequest.
        Excludes empty rows from the exports

        :param exclude_empty_rows: The exclude_empty_rows of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._exclude_empty_rows = exclude_empty_rows

    @property
    def has_split_by_media(self):
        """
        Gets the has_split_by_media of this ReportingExportJobRequest.
        Indicates if media type will be split in aggregate detail exports

        :return: The has_split_by_media of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._has_split_by_media

    @has_split_by_media.setter
    def has_split_by_media(self, has_split_by_media):
        """
        Sets the has_split_by_media of this ReportingExportJobRequest.
        Indicates if media type will be split in aggregate detail exports

        :param has_split_by_media: The has_split_by_media of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._has_split_by_media = has_split_by_media

    @property
    def has_summary_row(self):
        """
        Gets the has_summary_row of this ReportingExportJobRequest.
        Indicates if summary row needs to be present in exports

        :return: The has_summary_row of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._has_summary_row

    @has_summary_row.setter
    def has_summary_row(self, has_summary_row):
        """
        Sets the has_summary_row of this ReportingExportJobRequest.
        Indicates if summary row needs to be present in exports

        :param has_summary_row: The has_summary_row of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._has_summary_row = has_summary_row

    @property
    def csv_delimiter(self):
        """
        Gets the csv_delimiter of this ReportingExportJobRequest.
        The user supplied csv delimiter string value either of type 'comma' or 'semicolon' permitted for the export request

        :return: The csv_delimiter of this ReportingExportJobRequest.
        :rtype: str
        """
        return self._csv_delimiter

    @csv_delimiter.setter
    def csv_delimiter(self, csv_delimiter):
        """
        Sets the csv_delimiter of this ReportingExportJobRequest.
        The user supplied csv delimiter string value either of type 'comma' or 'semicolon' permitted for the export request

        :param csv_delimiter: The csv_delimiter of this ReportingExportJobRequest.
        :type: str
        """
        allowed_values = ["SEMICOLON", "COMMA"]
        if csv_delimiter.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for csv_delimiter -> " + csv_delimiter)
            self._csv_delimiter = "outdated_sdk_version"
        else:
            self._csv_delimiter = csv_delimiter

    @property
    def selected_columns(self):
        """
        Gets the selected_columns of this ReportingExportJobRequest.
        The list of ordered selected columns from the export view by the user

        :return: The selected_columns of this ReportingExportJobRequest.
        :rtype: list[SelectedColumns]
        """
        return self._selected_columns

    @selected_columns.setter
    def selected_columns(self, selected_columns):
        """
        Sets the selected_columns of this ReportingExportJobRequest.
        The list of ordered selected columns from the export view by the user

        :param selected_columns: The selected_columns of this ReportingExportJobRequest.
        :type: list[SelectedColumns]
        """
        
        self._selected_columns = selected_columns

    @property
    def has_custom_participant_attributes(self):
        """
        Gets the has_custom_participant_attributes of this ReportingExportJobRequest.
        Indicates if custom participant attributes will be exported

        :return: The has_custom_participant_attributes of this ReportingExportJobRequest.
        :rtype: bool
        """
        return self._has_custom_participant_attributes

    @has_custom_participant_attributes.setter
    def has_custom_participant_attributes(self, has_custom_participant_attributes):
        """
        Sets the has_custom_participant_attributes of this ReportingExportJobRequest.
        Indicates if custom participant attributes will be exported

        :param has_custom_participant_attributes: The has_custom_participant_attributes of this ReportingExportJobRequest.
        :type: bool
        """
        
        self._has_custom_participant_attributes = has_custom_participant_attributes

    @property
    def recipient_emails(self):
        """
        Gets the recipient_emails of this ReportingExportJobRequest.
        The list of email recipients for the exports

        :return: The recipient_emails of this ReportingExportJobRequest.
        :rtype: list[str]
        """
        return self._recipient_emails

    @recipient_emails.setter
    def recipient_emails(self, recipient_emails):
        """
        Sets the recipient_emails of this ReportingExportJobRequest.
        The list of email recipients for the exports

        :param recipient_emails: The recipient_emails of this ReportingExportJobRequest.
        :type: list[str]
        """
        
        self._recipient_emails = recipient_emails

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

